@@ -22,8 +22,15 @@
 
 # pylint: skip-file
 
+import sys
 from typing import TypeVar
 
+if sys.version_info >= (3, 8):
+    from typing import Protocol
+else:
+    from typing_extensions import Protocol
+
+
 T = TypeVar('T')
 U = TypeVar('U')
 A = TypeVar('A')
@@ -33,3 +40,19 @@ V = TypeVar('V')
 
 E = TypeVar('E')
 F = TypeVar('F')
+
+
+class SupportsDunderLT(Protocol):
+    def __lt__(self, __other: object) -> bool: ...
+
+
+class SupportsDunderGT(Protocol):
+    def __gt__(self, __other: object) -> bool: ...
+
+
+class SupportsDunderLE(Protocol):
+    def __le__(self, __other: object) -> bool: ...
+
+
+class SupportsDunderGE(Protocol):
+    def __ge__(self, __other: object) -> bool: ...
